Influence of body size and environmental conditions on parasite assemblages of the black-spotted croaker (Protonibea diacanthus) (Teleostei: Sciaenidae) in northern Australia
Marine Biology
Megan Porter* A, B, Diane P. Barton A, B, Joel Williams C, Jo Randall D, E, F, Otso Ovaskainen G, H, David A. Crook D, I and Shokoofeh Shamsi A, B
A School of Agricultural, Environmental and Veterinary Sciences, Charles Sturt University, Wagga Wagga, NSW 2678, Australia
B Gulbali Institute, Charles Sturt University, Wagga Wagga, NSW 2678, Australia 
C Institute for Marine and Antarctic Studies, University of Tasmania, Hobart, TAS 7000, Australia
D Research Institute for the Environment and Livelihoods, Charles Darwin University, Casuarina, NT 0810, Australia
E Australian Institute of Marine Science, Arafura Timor Research Facility, Casuarina, NT 0810, Australia
F Department of Industry, Tourism and Trade, Northern Territory Government of Australia, Berrimah, NT 0801, Australia
G Department of Biological and Environmental Science, University of Jyvskyl, P.O. Box 35 (Survontie 9C), FI-40014 Jyvskyl, Finland 
H Organismal and Evolutionary Biology Research Programme, Faculty of Biological and Environmental Sciences, University of Helsinki, P.O. Box 65, Helsinki 00014, Finland
I Department of Primary Industries, Narrandera Fisheries Centre, Narrandera, NSW 2700, Australia
* Corresponding author. Email: mporter@csu.edu.au; ORCID: 0000-0003-1404-1391 

Electronic Supplementary Material
Online Resource 1. R code file for the running of HMSC models and the production of figures.  

# Set the base directory using your favorite method
setwd("D:/Users/mporte35/Documents/PhD_Documents on project/Results/HMSC/base")
#S1_define_models_template
#
##################################################################################################
# INPUT AND OUTPUT OF THIS SCRIPT (BEGINNING)
##################################################################################################
#	INPUT. Original datafiles of the case study, placed in the data folder.

#	OUTPUT. Unfitted models, i.e., the list of Hmsc model(s) that have been defined
# but not fitted yet, stored in the file "models/unfitted_models.RData".
##################################################################################################
# INPUT AND OUTPUT OF THIS SCRIPT (END)
##################################################################################################


##################################################################################################
# MAKE THE SCRIPT REPRODUCIBLE (BEGINNING)
##################################################################################################
set.seed(1)
##################################################################################################
## MAKE THE SCRIPT REPRODUCIBLE (END)
##################################################################################################


##################################################################################################
# LOAD PACKAGES (BEGINNING)
##################################################################################################
library(Hmsc)
##################################################################################################
# LOAD PACKAGES (END)
##################################################################################################


##################################################################################################
# SET DIRECTORIES (BEGINNING)
##################################################################################################
localDir = "."
dataDir = file.path(localDir, "data")
modelDir = file.path(localDir, "models")
if(!dir.exists(modelDir)) dir.create(modelDir)
##################################################################################################
# SET DIRECTORIES (END)
##################################################################################################


##################################################################################################
# READ AND EXPLORE THE DATA (BEGINNING)
##################################################################################################
# Write here the code needed to read in the data, and explore it by (with View, plot, hist, ...)
# to get and idea of it and ensure that the data are consistent
data=read.csv(file.path(dataDir,"species.csv"))
Y=as.matrix(data[,2:12])

dim(Y)
head(Y)
#View(Y)
#hist(Y)

XData=read.csv(file.path(dataDir,"environment.csv"), as.is=FALSE)

dim(XData)
head(XData)
#View(XData)
str(XData)
XData$FishCode=as.factor(XData$FishCode)
XData$Season=as.factor(XData$Season)
XData$Sex=as.factor(XData$Sex)
XData$Year=as.factor(XData$Year)
#plot(XData)
#hist(XData$Length)

#P=colMeans(Y>0)
#hist(P)
#A=colSums(Y)/sum(Y)
#hist(A)

TrData=read.csv(file.path(dataDir,"traits.csv"),as.is=FALSE)

#TrData=data.frame(Species=alltraits$Species,ParasiteType=alltraits$ParasiteType)

#head(TrData)
all(colnames(Y)==TrData$Species)
#colnames(Y)
#TrData$Species
rownames(TrData)=TrData$Species
#View(TrData)
#plot(TrData)
#hist(TrData)
#str(TrData)

##################################################################################################
# READ AND EXPLORE THE DATA (END)
##################################################################################################

##################################################################################################
# SET UP THE MODEL (BEGINNING)
##################################################################################################
# Note that many of the components are optional 
# Here instructions are given at generic level, the details will depend on the model

# Organize the community data in the matrix Y

# Organize the environmental data into a dataframe XData
# Define the environmental model through XFormula
# XFormula = ~ ...

# Organize the trait data into a dataframe TrData
# Define the trait model through TrFormula
# TrFormula = ~ ..

# Set up a phylogenetic (or taxonomic tree) as myTree

# Define the studyDesign as a dataframe 
# For example, if you have sampled the same locations over multiple years, you may define
# studyDesign = data.frame(sample = ..., year = ..., location = ...)

# Set up the random effects
# For example, you may define year as an unstructured random effect
# rL.year = HmscRandomLevel(units = levels(studyDesign$year))
# For another example, you may define location as a spatial random effect
# rL.location = HmscRandomLevel(sData = locations.xy)
# Here locations.xy would be a matrix (one row per unique location)
# where row names are the levels of studyDesign$location,
# and the columns are the xy-coordinates
# For another example, you may define the sample = sampling unit = row of matrix Y
# as a random effect, in case you are interested in co-occurrences at that level
# rL.sample = HmscRandomLevel(units = levels(studyDesign$sample))

studyDesign=data.frame(FishCode=XData$FishCode, Year=XData$Year, Location=XData$Location)
#head(studyDesign)
#dim(studyDesign)
#studyDesign$Location
#Can check other levels of studyDesign with FishCode and Year

rL.Year=HmscRandomLevel(units=levels(studyDesign$Year)) #O2 added levels
rL.Location=HmscRandomLevel(units=levels(studyDesign$Location)) #O2 added levels

Y.pa = 1*(Y>0)
Y.abuc = Y
Y.abuc[Y==0] = NA
Y.abuc = scale(log(Y.abuc))
#XFormula = ~Season + Length + Sex + Salinity 
XFormula = ~Season + Length + Sex + LowDO + LowTemp + Salinity + NH + TDN + TDP
TrFormula = ~ParasiteType
m.pa = Hmsc(Y=Y.pa,
          XData = XData,  XFormula=XFormula,
         studyDesign = studyDesign, TrData = TrData, TrFormula = TrFormula,
        ranLevels=list(Year=rL.Year, Location = rL.Location), distr= "probit")

m.abuc = Hmsc(Y=Y.abuc,
            XData = XData,  XFormula=XFormula,
            studyDesign = studyDesign, TrData = TrData, TrFormula = TrFormula,
            ranLevels=list(Year=rL.Year, Location = rL.Location), distr= "normal")

models = list(m.pa,m.abuc)
names(models) = c("pa","abuc")
save(models,file=file.path(modelDir,"unfitted_models.RData"))
##################################################################################################
# TESTING THAT MODELS FIT WITHOUT ERRORS (START)
##################################################################################################
for(i in 1:length(models)){
  print(i)
  sampleMcmc(models[[i]],samples=2)
}
##################################################################################################
# TESTING THAT MODELS FIT WITHOUT ERRORS (END)
##################################################################################################

#S2_fit_models
#
# Set the base directory using your favorite method
# setwd("...")

##################################################################################################
# INPUT AND OUTPUT OF THIS SCRIPT (BEGINNING)
##################################################################################################
#	INPUT. Unfitted models.

#	OUTPUT. Fitted models, with fitting done for multiple RUNs:
# first short MCMC chains (to provide some results fast), and then with increasingly long MCMC chains
# (until MCMC convergence or computational limit is reached): the files
# "models/models_thin_1_samples_5_chains_4.Rdata" (RUN 0),
# "models/models_thin_1_samples_250_chains_4.Rdata" (RUN 1),
# "models/models_thin_10_samples_250_chains_4.Rdata" (RUN 2), 
# "models/models_thin_100_samples_250_chains_4.Rdata" (RUN 3), and so on.
##################################################################################################
# INPUT AND OUTPUT OF THIS SCRIPT (END)
##################################################################################################


##################################################################################################
# SETTING COMMONLY ADJUSTED PARAMETERS TO NULL WHICH CORRESPONDS TO DEFAULT CHOICE (BEGINNING)
##################################################################################################
nParallel = NULL #Default: nParallel = nChains
##################################################################################################
# SETTING COMMONLY ADJUSTED PARAMETERS TO NULL WHICH CORRESPONDS TO DEFAULT CHOICE (END)
##################################################################################################

##################################################################################################
# CHANGE DEFAULT OPTIONS BY REMOVING COMMENT AND SETTING VALUE (BEGINNING)
# NOTE THAT THIS IS THE ONLY SECTION OF THE SCRIPT THAT YOU TYPICALLY NEED TO MODIFY
##################################################################################################
#nParallel = 1 #Set to 1 to disable parallel computing
##################################################################################################
# CHANGE DEFAULT OPTIONS BY REMOVING COMMENT AND SETTING VALUE (END)
# NOTE THAT THIS IS THE ONLY SECTION OF THE SCRIPT THAT YOU TYPICALLY NEED TO MODIFY
##################################################################################################

##################################################################################################
# SET DIRECTORIES (BEGINNING)
##################################################################################################
localDir = "."
modelDir = file.path(localDir, "models")
##################################################################################################
# SET DIRECTORIES (END)
##################################################################################################

library(Hmsc)

load(file=file.path(modelDir,"unfitted_models.RData"))
nm = length(models)
samples_list = c(5,250,250,250,250,250)
thin_list = c(1,1,10,100,1000,10000)
nChains = 4
if(is.null(nParallel)) nParallel = nChains
Lst = 1
while(Lst <= length(samples_list)){
  thin = thin_list[Lst]
  samples = samples_list[Lst]
  print(paste0("thin = ",as.character(thin),"; samples = ",as.character(samples)))
  filename = file.path(modelDir,paste("models_thin_", as.character(thin),
                                             "_samples_", as.character(samples),
                                             "_chains_",as.character(nChains),
                                             ".Rdata",sep = ""))
  if(file.exists(filename)){
    print("model had been fitted already")
  } else {
    print(date())
    for (mi in 1:nm) {
      print(paste0("model = ",names(models)[mi]))
      m = models[[mi]]
      m = sampleMcmc(m, samples = samples, thin=thin,
                     adaptNf=rep(ceiling(0.4*samples*thin),m$nr), 
                     transient = ceiling(0.5*samples*thin),
                     nChains = nChains,
                     nParallel = nParallel) 
      models[[mi]] = m
    }
    save(models,file=filename)
  }
  Lst = Lst + 1
}

#S3_evaluate_convergence
#
# Set the base directory using your favorite method
# setwd("...")

##################################################################################################
# INPUT AND OUTPUT OF THIS SCRIPT (BEGINNING)
##################################################################################################
#	INPUT. Fitted models

#	OUTPUT. MCMC convergence statistics for selected model parameters,
# illustrated (for all RUNs performed thus far in S3) in the file "results/MCMC_convergence.pdf",
# and the text file "results/MCMC_convergence.txt".
##################################################################################################
# INPUT AND OUTPUT OF THIS SCRIPT (END)
##################################################################################################


##################################################################################################
# MAKE THE SCRIPT REPRODUCIBLE (BEGINNING)
##################################################################################################
set.seed(1)
##################################################################################################
## MAKE THE SCRIPT REPRODUCIBLE (END)
##################################################################################################


##################################################################################################
# SETTING COMMONLY ADJUSTED PARAMETERS TO NULL WHICH CORRESPONDS TO DEFAULT CHOICE (BEGINNING)
##################################################################################################
showBeta = NULL #Default: showBeta = TRUE, convergence shown for beta-parameters
showGamma = NULL #Default: showGamma = FALSE, convergence not shown for gamma-parameters
showOmega = NULL #Default: showOmega = FALSE, convergence not shown for Omega-parameters
maxOmega = NULL #Default: convergence of Omega shown for 50 randomly selected species pairs
showRho = NULL #Default: showRho = FALSE, convergence not shown for rho-parameters
showAlpha = NULL #Default: showAlpha = FALSE, convergence not shown for alpha-parameters
##################################################################################################
# SETTING COMMONLY ADJUSTED PARAMETERS TO NULL WHICH CORRESPONDS TO DEFAULT CHOICE (END)
##################################################################################################

##################################################################################################
# CHANGE DEFAULT OPTIONS BY REMOVING COMMENT AND SETTING VALUE (BEGINNING)
# NOTE THAT THIS IS THE ONLY SECTION OF THE SCRIPT THAT YOU TYPICALLY NEED TO MODIFY
##################################################################################################
showBeta = TRUE
showGamma = TRUE
showOmega = TRUE
maxOmega = 100
showRho = TRUE
showAlpha = TRUE
##################################################################################################
# CHANGE DEFAULT OPTIONS BY REMOVING COMMENT AND SETTING VALUE (END)
# NOTE THAT THIS IS THE ONLY SECTION OF THE SCRIPT THAT YOU TYPICALLY NEED TO MODIFY
##################################################################################################

##################################################################################################
# SET DIRECTORIES (BEGINNING)
##################################################################################################
localDir = "."
modelDir = file.path(localDir, "models")
resultDir = file.path(localDir, "results")
if (!dir.exists(resultDir)) dir.create(resultDir)
##################################################################################################
# SET DIRECTORIES (END)
##################################################################################################

if(is.null(showBeta)) showBeta = TRUE
if(is.null(showGamma)) showGamma = FALSE
if(is.null(showOmega)) showOmega = FALSE
if(is.null(maxOmega)) maxOmega = 50
if(is.null(showRho)) showRho = FALSE
if(is.null(showAlpha)) showAlpha = FALSE

library(Hmsc)
library(colorspace)
library(vioplot)

samples_list = c(5,250,250,250,250,250)
thin_list = c(1,1,10,100,1000,10000)
nst = length(thin_list)
nChains = 4

text.file = file.path(resultDir,"/MCMC_convergence.txt")
cat("MCMC Convergennce statistics\n\n",file=text.file,sep="")

ma.beta = NULL
na.beta = NULL
ma.gamma = NULL
na.gamma = NULL
ma.omega= NULL
na.omega = NULL
ma.alpha = NULL
na.alpha = NULL  
ma.rho = NULL
na.rho = NULL
Lst = 1
while(Lst <= nst){
  thin = thin_list[Lst]
  samples = samples_list[Lst]
  
  
  filename = file.path(modelDir,paste("models_thin_", as.character(thin),
                                      "_samples_", as.character(samples),
                                      "_chains_",as.character(nChains),
                                      ".Rdata",sep = ""))
  if(file.exists(filename)){
    load(filename)
    cat(c("\n",filename,"\n\n"),file=text.file,sep="",append=TRUE)
    nm = length(models)
    for(j in 1:nm){
      mpost = convertToCodaObject(models[[j]], spNamesNumbers = c(T,F), covNamesNumbers = c(T,F))
      nr = models[[j]]$nr
      cat(c("\n",names(models)[j],"\n\n"),file=text.file,sep="",append=TRUE)
      if(showBeta){
        psrf = gelman.diag(mpost$Beta,multivariate=FALSE)$psrf
        tmp = summary(psrf)
        cat("\nbeta\n\n",file=text.file,sep="",append=TRUE)
        cat(tmp[,1],file=text.file,sep="\n",append=TRUE)
        if(is.null(ma.beta)){
          ma.beta = psrf[,1]
          na.beta = paste0(as.character(thin),",",as.character(samples))
        } else {
          ma.beta = cbind(ma.beta,psrf[,1])
          if(j==1){
            na.beta = c(na.beta,paste0(as.character(thin),",",as.character(samples)))
          } else {
            na.beta = c(na.beta,"")
          }
        }
      }
      if(showGamma){
        psrf = gelman.diag(mpost$Gamma,multivariate=FALSE)$psrf
        tmp = summary(psrf)
        cat("\ngamma\n\n",file=text.file,sep="",append=TRUE)
        cat(tmp[,1],file=text.file,sep="\n",append=TRUE)
        if(is.null(ma.gamma)){
          ma.gamma = psrf[,1]
          na.gamma = paste0(as.character(thin),",",as.character(samples))
        } else {
          ma.gamma = cbind(ma.gamma,psrf[,1])
          if(j==1){
            na.gamma = c(na.gamma,paste0(as.character(thin),",",as.character(samples)))
          } else {
            na.gamma = c(na.gamma,"")
          }
        }
      }
      if(showRho & !is.null(mpost$Rho)){
        psrf = gelman.diag(mpost$Rho,multivariate=FALSE)$psrf
        cat("\nrho\n\n",file=text.file,sep="",append=TRUE)
        cat(psrf[1],file=text.file,sep="\n",append=TRUE)
      }
      if(showOmega & nr>0){
        cat("\nomega\n\n",file=text.file,sep="",append=TRUE)
        for(k in 1:nr){
          cat(c("\n",names(models[[j]]$ranLevels)[k],"\n\n"),file=text.file,sep="",append=TRUE)
          tmp = mpost$Omega[[k]]
          z = dim(tmp[[1]])[2]
          if(z > maxOmega){
            sel = sample(1:z, size = maxOmega)
            for(i in 1:length(tmp)){
              tmp[[i]] = tmp[[i]][,sel]
            }
          }
          psrf = gelman.diag(tmp, multivariate = FALSE)$psrf
          tmp = summary(psrf)
          cat(tmp[,1],file=text.file,sep="\n",append=TRUE)
          if(is.null(ma.omega)){
            ma.omega = psrf[,1]
            na.omega = paste0(as.character(thin),",",as.character(samples))
          } else {
            ma.omega = cbind(ma.omega,psrf[,1])
            if(j==1){
              na.omega = c(na.omega,paste0(as.character(thin),",",as.character(samples)))
            } else {
              na.omega = c(na.omega,"")
            }
          }
        }
      }
      if(showAlpha & nr>0){
        for(k in 1:nr){
          if(models[[j]]$ranLevels[[k]]$sDim>0){
            cat("\nalpha\n\n",file=text.file,sep="\n",append=TRUE)
            cat(c("\n",names(models[[j]]$ranLevels)[k],"\n\n"),file=text.file,sep="",append=TRUE)
            psrf = gelman.diag(mpost$Alpha[[k]],multivariate = FALSE)$psrf
            cat(psrf[,1],file=text.file,sep="\n",append=TRUE)            
          }
        }
      }
    }
  }
  Lst = Lst + 1
}

pdf(file= file.path(resultDir,"/MCMC_convergence.pdf"))
if(showBeta){
  par(mfrow=c(2,1))
  vioplot(ma.beta,col=rainbow_hcl(nm),names=na.beta,ylim=c(0,max(ma.beta)),main="psrf(beta)")
  legend("topright",legend = names(models), fill=rainbow_hcl(nm))
  vioplot(ma.beta,col=rainbow_hcl(nm),names=na.beta,ylim=c(0.9,1.1),main="psrf(beta)")
}
if(showGamma){
  par(mfrow=c(2,1))
  vioplot(ma.gamma,col=rainbow_hcl(nm),names=na.gamma,ylim=c(0,max(ma.gamma)),main="psrf(gamma)")
  legend("topright",legend = names(models), fill=rainbow_hcl(nm))
  vioplot(ma.gamma,col=rainbow_hcl(nm),names=na.gamma,ylim=c(0.9,1.1),main="psrf(gamma)")
}
if(showOmega & !is.null(ma.omega)){
  par(mfrow=c(2,1))
  vioplot(ma.omega,col=rainbow_hcl(nm),names=na.omega,ylim=c(0,max(ma.omega)),main="psrf(omega)")
  legend("topright",legend = names(models), fill=rainbow_hcl(nm))
  vioplot(ma.omega,col=rainbow_hcl(nm),names=na.omega,ylim=c(0.9,1.1),main="psrf(omega)")
}
dev.off()

#S4_compute_model
#
# Set the base directory using your favorite method
# setwd("...")

##################################################################################################
# INPUT AND OUTPUT OF THIS SCRIPT (BEGINNING)
##################################################################################################
# INPUT. Fitted models.

#	OUTPUT. Model fits computed by the cross-validation, with fitting
# (which is part of cross-validation) done for multiple RUNs:
# first short MCMC chains (to provide some results fast), and then with increasingly long MCMC chains
# (up to the longest run performed in S2). The results are stored in the files
# "models/MF_thin_1_samples_5_chains_4.Rdata" (RUN 0),
# "models/MF_thin_1_samples_250_chains_4.Rdata" (RUN 1),
# "models/MF_thin_10_samples_250_chains_4.Rdata" (RUN 2), 
# "models/MF_thin_100_samples_250_chains_4.Rdata" (RUN 3), and so on.
##################################################################################################
# INPUT AND OUTPUT OF THIS SCRIPT (END)
##################################################################################################


##################################################################################################
# MAKE THE SCRIPT REPRODUCIBLE (BEGINNING)
##################################################################################################
set.seed(1)
##################################################################################################
## MAKE THE SCRIPT REPRODUCIBLE (END)
##################################################################################################


##################################################################################################
# SETTING COMMONLY ADJUSTED PARAMETERS TO NULL WHICH CORRESPONDS TO DEFAULT CHOICE (BEGINNING)
##################################################################################################
nfolds = NULL #Default: two-fold cross-validation
nParallel = NULL #Default: nParallel = nChains
##################################################################################################
# SETTING COMMONLY ADJUSTED PARAMETERS TO NULL WHICH CORRESPONDS TO DEFAULT CHOICE (END)
##################################################################################################

##################################################################################################
# CHANGE DEFAULT OPTIONS BY REMOVING COMMENT AND SETTING VALUE (BEGINNING)
# NOTE THAT THIS IS THE ONLY SECTION OF THE SCRIPT THAT YOU TYPICALLY NEED TO MODIFY
##################################################################################################
#nfolds = 10 #change the number of CV-folds
#nParallel = 1 #Set to 1 to disable parallel computing
##################################################################################################
# CHANGE DEFAULT OPTIONS BY REMOVING COMMENT AND SETTING VALUE (END)
# NOTE THAT THIS IS THE ONLY SECTION OF THE SCRIPT THAT YOU TYPICALLY NEED TO MODIFY
##################################################################################################

##################################################################################################
# SET DIRECTORIES (BEGINNING)
##################################################################################################
localDir = "."
modelDir = file.path(localDir, "models")
##################################################################################################
# SET DIRECTORIES (END)
##################################################################################################

if(is.null(nfolds)) nfolds = 2

library(Hmsc)
samples_list = c(5,250,250,250,250,250)
thin_list = c(1,1,10,100,1000,10000)
nChains = 4
if(is.null(nParallel)) nParallel = nChains
Lst = 1
while(Lst <= length(samples_list)){
  thin = thin_list[Lst]
  samples = samples_list[Lst]
  filename.in = file.path(modelDir,paste("models_thin_", as.character(thin),
                                         "_samples_", as.character(samples),
                                         "_chains_",as.character(nChains),
                                         ".Rdata",sep = ""))
  filename.out = file.path(modelDir,paste("MF_thin_", as.character(thin),
                                          "_samples_", as.character(samples),
                                          "_chains_",as.character(nChains),
                                          "_nfolds_", as.character(nfolds),
                                          ".Rdata",sep = ""))
  if(file.exists(filename.out)){
    print(paste0("thin = ",as.character(thin),"; samples = ",as.character(samples)))
    print("model fit had been computed already")
  } else {
    if(file.exists(filename.in)){
      print(paste0("thin = ",as.character(thin),"; samples = ",as.character(samples)))
      print(date())
      load(file = filename.in) #models
      nm = length(models)
      
      MF = list()
      MFCV = list()
      WAIC = list()
      
      for(mi in 1:nm){
        print(paste0("model = ",names(models)[mi]))
        m = models[[mi]]
        preds = computePredictedValues(m)
        MF[[mi]] = evaluateModelFit(hM=m, predY=preds)
        partition = createPartition(m, nfolds = nfolds) #USE column = ...
        preds = computePredictedValues(m,partition=partition, nParallel = nParallel)
        MFCV[[mi]] = evaluateModelFit(hM=m, predY=preds)
        WAIC[[mi]] = computeWAIC(m)
      }
      names(MF)=names(models)
      names(MFCV)=names(models)
      names(WAIC)=names(models)
      
      save(MF,MFCV,WAIC,file = filename.out)
    }
  }
  Lst = Lst + 1
}

#S5_show_model_fit
#
# Set the base directory using your favorite method
# setwd("...")

##################################################################################################
# INPUT AND OUTPUT OF THIS SCRIPT (BEGINNING)
##################################################################################################
#	INPUT. Model fits.

#	OUTPUT. Model fits illustrated (for highest RUN of S4) in the file "results/model_fit.pdf".
##################################################################################################
# INPUT AND OUTPUT OF THIS SCRIPT (END)
##################################################################################################



##################################################################################################
# MAKE THE SCRIPT REPRODUCIBLE (BEGINNING)
##################################################################################################
set.seed(1)
##################################################################################################
## MAKE THE SCRIPT REPRODUCIBLE (END)
##################################################################################################



##################################################################################################
# SETTING COMMONLY ADJUSTED PARAMETERS TO NULL WHICH CORRESPONDS TO DEFAULT CHOICE (BEGINNING)
##################################################################################################
nfolds = NULL #Default: two-fold cross-validation
##################################################################################################
# SETTING COMMONLY ADJUSTED PARAMETERS TO NULL WHICH CORRESPONDS TO DEFAULT CHOICE (END)
##################################################################################################

##################################################################################################
# CHANGE DEFAULT OPTIONS BY REMOVING COMMENT AND SETTING VALUE (BEGINNING)
# NOTE THAT THIS IS THE ONLY SECTION OF THE SCRIPT THAT YOU TYPICALLY NEED TO MODIFY
##################################################################################################
#nfolds = 10 #change the number of CV-folds
##################################################################################################
# CHANGE DEFAULT OPTIONS BY REMOVING COMMENT AND SETTING VALUE (END)
# NOTE THAT THIS IS THE ONLY SECTION OF THE SCRIPT THAT YOU TYPICALLY NEED TO MODIFY
##################################################################################################

##################################################################################################
# SET DIRECTORIES (BEGINNING)
##################################################################################################
localDir = "."
modelDir = file.path(localDir, "models")
resultDir = file.path(localDir, "results")
if (!dir.exists(resultDir)) dir.create(resultDir)
##################################################################################################
# SET DIRECTORIES (END)
##################################################################################################

if(is.null(nfolds)) nfolds = 2

library(Hmsc)

samples_list = c(5,250,250,250,250,250)
thin_list = c(1,1,10,100,1000,10000)
nst = length(thin_list)
nChains = 4

for (Lst in nst:1) {
  thin = thin_list[Lst]
  samples = samples_list[Lst]
  
  filename = file.path(modelDir,paste("MF_thin_", as.character(thin),
                                      "_samples_", as.character(samples),
                                      "_chains_",as.character(nChains),
                                      "_nfolds_", as.character(nfolds),
                                      ".Rdata",sep = ""))
  if(file.exists(filename)){break}
}
if(file.exists(filename)){
  load(filename)
  
  nm = length(MF)
  modelnames = names(MF)
  pdf(file = file.path(resultDir,paste0("/model_fit_nfolds_",nfolds,".pdf")))
  for(j in 1:nm){
    cMF = MF[[j]]
    cMFCV = MFCV[[j]]
    if(!is.null(cMF$TjurR2)){
      plot(cMF$TjurR2,cMFCV$TjurR2,xlim=c(-1,1),ylim=c(-1,1),
           xlab = "explanatory power",
           ylab = "predictive power",
           main=paste0(modelnames[j],", thin = ",
                       as.character(thin),
                       ", samples = ",as.character(samples),
                       ": Tjur R2.\n",
                       "mean(MF) = ",as.character(mean(cMF$TjurR2,na.rm=TRUE)),
                       ", mean(MFCV) = ",as.character(mean(cMFCV$TjurR2,na.rm=TRUE))))
      abline(0,1)
      abline(v=0)
      abline(h=0)
    }
    if(!is.null(cMF$R2)){
      plot(cMF$R2,cMFCV$R2,xlim=c(-1,1),ylim=c(-1,1),
           xlab = "explanatory power",
           ylab = "predictive power",
           main=paste0(modelnames[[j]],", thin = ",as.character(thin),
                       ", samples = ",as.character(samples),
                       ": R2. \n",
                       "mean(MF) = ",as.character(mean(cMF$R2,na.rm=TRUE)),
                       ", mean(MFCV) = ",as.character(mean(cMFCV$R2,na.rm=TRUE))))
      abline(0,1)
      abline(v=0)
      abline(h=0)
    }
    if(!is.null(cMF$AUC)){
      plot(cMF$AUC,cMFCV$AUC,xlim=c(0,1),ylim=c(0,1),
           xlab = "explanatory power",
           ylab = "predictive power",
           main=paste0(modelnames[[j]],", thin = ",as.character(thin),
                       ", samples = ",as.character(samples),
                       ": AUC. \n",
                       "mean(MF) = ",as.character(mean(cMF$AUC,na.rm=TRUE)),
                       ", mean(MFCV) = ",as.character(mean(cMFCV$AUC,na.rm=TRUE))))
      abline(0,1)
      abline(v=0.5)
      abline(h=0.5)
    }
    if(FALSE && !is.null(cMF$O.TjurR2)){
      plot(cMF$O.TjurR2,cMFCV$O.TjurR2,xlim=c(-1,1),ylim=c(-1,1),
           xlab = "explanatory power",
           ylab = "predictive power",
           main=paste0(modelnames[[j]],", thin = ",as.character(thin),", samples = ",as.character(samples),": O.Tjur R2"))
      abline(0,1)
      abline(v=0)
      abline(h=0)
    }
    if(FALSE && !is.null(cMF$O.AUC)){
      plot(cMF$O.AUC,cMFCV$O.AUC,xlim=c(0,1),ylim=c(0,1),
           xlab = "explanatory power",
           ylab = "predictive power",
           main=paste0(modelnames[[j]],", thin = ",as.character(thin),", samples = ",as.character(samples),": O.AUC"))
      abline(0,1)
      abline(v=0.5)
      abline(h=0.5)
    }      
    if(!is.null(cMF$SR2)){
      plot(cMF$SR2,cMFCV$SR2,xlim=c(-1,1),ylim=c(-1,1),
           xlab = "explanatory power",
           ylab = "predictive power",
           main=paste0(modelnames[[j]],", thin = ",as.character(thin),
                       ", samples = ",as.character(samples),
                       ": SR2. \n",
                       "mean(MF) = ",as.character(mean(cMF$SR2,na.rm=TRUE)),
                       ", mean(MFCV) = ",as.character(mean(cMFCV$SR2,na.rm=TRUE))))
      abline(0,1)
      abline(v=0)
      abline(h=0)
    }    
    if(FALSE && !is.null(cMF$C.SR2)){
      plot(cMF$C.SR2,cMFCV$C.SR2,xlim=c(-1,1),ylim=c(-1,1),
           xlab = "explanatory power",
           ylab = "predictive power",
           main=paste0(modelnames[[j]],", thin = ",as.character(thin),", samples = ",as.character(samples),": C.SR2"))
      abline(0,1)
      abline(v=0)
      abline(h=0)
    }  
  }
  dev.off()
}

#S6_show_parameter_estimates
#
# Set the base directory using your favorite method
# setwd("...")

##################################################################################################
# INPUT AND OUTPUT OF THIS SCRIPT (BEGINNING)
##################################################################################################
#	INPUT. the Fitted models.

# OUTPUT: Parameter estimates illustrated (for highest RUN of S2) in the file
# "results/parameter_estimates.pdf", the text file "results/parameter_estimates.txt", 
# as well as given numerically in multiple csv files (one per parameter type) named 
# "results/parameter_estimates_[parameter_name].csv".
##################################################################################################
# INPUT AND OUTPUT OF THIS SCRIPT (END)
##################################################################################################


##################################################################################################
# MAKE THE SCRIPT REPRODUCIBLE (BEGINNING)
##################################################################################################
set.seed(1)
##################################################################################################
## MAKE THE SCRIPT REPRODUCIBLE (END)
##################################################################################################


##################################################################################################
# SETTING COMMONLY ADJUSTED PARAMETERS TO NULL WHICH CORRESPONDS TO DEFAULT CHOICE (BEGINNING)
##################################################################################################
support.level.beta = NULL #Default: 0.95
support.level.gamma = NULL #Default: 0.95
support.level.omega = NULL #Default: 0.9
var.part.order.explained = NULL #Default: in variance partitioning of explained variance, species are shown in the order they are in the model
var.part.order.raw = NULL #Default: in variance partitioning of raw variance, species are shown in the order they are in the model
show.sp.names.beta = NULL #Default: species names shown in beta plot if there are at most 30 species and no phylogeny
plotTree = NULL #Default: tree is plotted in Beta plot if the model includes it
omega.order = NULL #Default: species shown in the order they are in the model
show.sp.names.omega = NULL #Default: species names shown in beta plot if there are at most 30 species
##################################################################################################
# SETTING COMMONLY ADJUSTED PARAMETERS TO NULL WHICH CORRESPONDS TO DEFAULT CHOICE (END)
##################################################################################################

##################################################################################################
# CHANGE DEFAULT OPTIONS BY REMOVING COMMENT AND SETTING VALUE (BEGINNING)
# NOTE THAT THIS IS THE ONLY SECTION OF THE SCRIPT THAT YOU TYPICALLY NEED TO MODIFY
##################################################################################################
#use support levels to selected the level of statistical support shown
#support.level.beta = 0.8
#support.level.gamma = 0.8
#support.level.omega = 0.8

#use var.part.order.explained to select which order species are shown in the raw variance partitioning
#var.part.order.raw should be a list of length the number of models. 
#for each element provide either 0 (use default);
#or a vector of species indices;
#or "decreasing" if you wish to order according to explanatory power
#var.part.order.explained = list()
#var.part.order.explained[[1]] = 0
#var.part.order.explained[[2]] = c(2,1)

#use var.part.order.raw to select which order species are shown in the explained variance partitioning
#same options apply as for var.part.order.explained
#var.part.order.raw = list()
#var.part.order.raw[[1]] = "decreasing"
#var.part.order.raw[[2]] = c(1,2)

#use show.sp.names.beta to choose to show / not show species names in betaPlot
#if given, show.sp.names.beta should be a vector with length equalling number of models
#show.sp.names.beta = c(TRUE,FALSE)

#use plotTree to choose to plot / not plot the tree in betaPlot
#if given, plotTree should be a vector with length equalling number of models
#plotTree = c(FALSE,FALSE)

#use omega.order to select which order species are shown in omega plots
#omega.order should be a list of length the number of models. 
#for each element provide either 0 (use default);
#or a vector of species indices;
#or "AOE" if you wish to use the angular order of the eigenvectors.
#omega.order = list()
#omega.order[[1]] = "AOE"
#omega.order[[2]] = c(2,1)
#Default: species shown in the order they are in the model
#show.sp.names.omega = c(TRUE,FALSE) #Default: species names shown in beta plot if there are at most 30 species
##################################################################################################
# CHANGE DEFAULT OPTIONS BY REMOVING COMMENT AND SETTING VALUE (END)
# NOTE THAT THIS IS THE ONLY SECTION OF THE SCRIPT THAT YOU TYPICALLY NEED TO MODIFY
##################################################################################################

##################################################################################################
# SET DIRECTORIES (BEGINNING)
##################################################################################################
localDir = "."
modelDir = file.path(localDir, "models")
resultDir = file.path(localDir, "results")
if (!dir.exists(resultDir)) dir.create(resultDir)
##################################################################################################
# SET DIRECTORIES (END)
##################################################################################################

if(is.null(support.level.beta)) support.level.beta = 0.95
if(is.null(support.level.gamma)) support.level.gamma =  0.95
if(is.null(support.level.omega)) support.level.omega =  0.9

library(Hmsc)
library(colorspace)
library(corrplot)
library(writexl)

samples_list = c(5,250,250,250,250,250)
thin_list = c(1,1,10,100,1000,10000)
nst = length(thin_list)
nChains = 4

text.file = file.path(resultDir,"/parameter_estimates.txt")
cat(c("This file contains additional information regarding parameter estimates.","\n","\n",sep=""),file=text.file)

for (Lst in nst:1) {
  thin = thin_list[Lst]
  samples = samples_list[Lst]
  filename = file.path(modelDir,paste("models_thin_", as.character(thin),
                                      "_samples_", as.character(samples),
                                      "_chains_",as.character(nChains),
                                      ".Rdata",sep = ""))
  if(file.exists(filename)){break}
}
if(file.exists(filename)){
  load(filename)
  cat(c("\n",filename,"\n","\n"),file=text.file,sep="",append=TRUE)
  nm = length(models)
  if(is.null(var.part.order.explained)){
    var.part.order.explained = list()
    for(j in 1:nm) var.part.order.explained[[j]] = 0
  }
  if(is.null(var.part.order.raw)){
    var.part.order.raw = list()
    for(j in 1:nm) var.part.order.raw[[j]] = 0
  }
  if(is.null(omega.order)){
    omega.order = list()
    for(j in 1:nm) omega.order[[j]] = 0
  }
  
  modelnames = names(models)
  
  pdf(file= file.path(resultDir,"parameter_estimates.pdf"))
  for(j in 1:nm){
    cat(c("\n",names(models)[j],"\n","\n"),file=text.file,sep="",append=TRUE)
    m = models[[j]]
    if(m$XFormula=="~."){
      covariates = colnames(m$X)[-1]
    } else {
      covariates = attr(terms(m$XFormula),"term.labels")
    }
    if(m$nr+length(covariates)>1 & m$ns>1){
      preds = computePredictedValues(m)
      VP = computeVariancePartitioning(m)
      vals = VP$vals
      mycols = rainbow(nrow(VP$vals))
      MF = evaluateModelFit(hM=m, predY=preds)
      R2 = NULL
      if(!is.null(MF$TjurR2)){
        TjurR2 = MF$TjurR2
        vals = rbind(vals,TjurR2)
        R2=TjurR2
      }
      if(!is.null(MF$R2)){
        R2=MF$R2
        vals = rbind(vals,R2)
      }
      if(!is.null(MF$SR2)){
        R2=MF$SR2
        vals = rbind(vals,R2)
      }
      filename = file.path(resultDir, paste("parameter_estimates_VP_",modelnames[j],".csv"))
      write.csv(vals,file=filename)
      if(!is.null(VP$R2T$Beta)){
        filename = file.path(resultDir,paste("parameter_estimates_VP_R2T_Beta",modelnames[j],".csv"))
        write.csv(VP$R2T$Beta,file=filename)
      }
      if(!is.null(VP$R2T$Y)){
        filename = file.path(resultDir, paste("parameter_estimates_VP_R2T_Y",modelnames[j],".csv"))
        write.csv(VP$R2T$Y,file=filename)
      }
      if(all(var.part.order.explained[[j]]==0)){
        c.var.part.order.explained = 1:m$ns
      } else {
        if(all(var.part.order.explained[[j]]=="decreasing")){
          c.var.part.order.explained = order(R2, decreasing = TRUE)
        }
        else {
          c.var.part.order.explained  = var.part.order.explained[[j]]
        }
      }
      VP$vals = VP$vals[,c.var.part.order.explained]
      cat(c("\n","var.part.order.explained","\n","\n"),file=text.file,sep="",append=TRUE)
      cat(m$spNames[c.var.part.order.explained],file=text.file,sep="\n",append=TRUE)
      plotVariancePartitioning(hM=m, VP=VP, main = paste0("Proportion of explained variance, ",modelnames[j]), cex.main=0.8, cols = mycols, args.leg=list(bg="white",cex=0.7))
      if(all(var.part.order.raw[[j]]==0)){
        c.var.part.order.raw = 1:m$ns
      } else {
        if(all(var.part.order.raw[[j]]=="decreasing")){
          c.var.part.order.raw = order(R2, decreasing = TRUE)
        }
        else {
          c.var.part.order.raw  = var.part.order.raw[[j]]
        }
      }
      if(!is.null(R2)){
        VPr = VP
        for(k in 1:m$ns){
          VPr$vals[,k] = R2[k]*VPr$vals[,k]
        }
        VPr$vals = VPr$vals[,c.var.part.order.raw]
        cat(c("\n","var.part.order.raw","\n","\n"),file=text.file,sep="",append=TRUE)
        cat(m$spNames[c.var.part.order.raw],file=text.file,sep="\n",append=TRUE)
        plotVariancePartitioning(hM=m, VP=VPr,main=paste0("Proportion of raw variance, ",modelnames[j]),cex.main=0.8, cols = mycols, args.leg=list(bg="white",cex=0.7),ylim=c(0,1))
      }
    }
  }
  for(j in 1:nm){
    m = models[[j]]
    if(m$nc>1){
      postBeta = getPostEstimate(m, parName="Beta")
      filename = file.path(resultDir, paste("parameter_estimates_Beta_",modelnames[j],".xlsx"))
      me = as.data.frame(t(postBeta$mean))
      me = cbind(m$spNames,me)
      colnames(me) = c("Species",m$covNames)
      po = as.data.frame(t(postBeta$support))
      po = cbind(m$spNames,po)
      colnames(po) = c("Species",m$covNames)
      ne = as.data.frame(t(postBeta$supportNeg))
      ne = cbind(m$spNames,ne)
      colnames(ne) = c("Species",m$covNames)
      vals = list("Posterior mean"=me,"Pr(x>0)"=po,"Pr(x<0)"=ne)
      writexl::write_xlsx(vals,path = filename)
      if(is.null(show.sp.names.beta)){
        c.show.sp.names = (is.null(m$phyloTree) && m$ns<=30) 
      } else {
        c.show.sp.names = show.sp.names.beta[j]
      }
      c.plotTree = !is.null(m$phyloTree)
      if(!is.null(plotTree)){
        c.plotTree = c.plotTree & plotTree[j]
      }
      plotBeta(m, post=postBeta, supportLevel = support.level.beta, param="Sign",
               plotTree = c.plotTree,
               covNamesNumbers = c(TRUE,FALSE),
               spNamesNumbers=c(c.show.sp.names,FALSE),
               cex=c(0.6,0.6,0.8))
      mymain = paste0("BetaPlot, ",modelnames[j])
      if(!is.null(m$phyloTree)){
        mpost = convertToCodaObject(m)
        rhovals = unlist(poolMcmcChains(mpost$Rho))
        mymain = paste0(mymain,", E[rho] = ",round(mean(rhovals),2),", Pr[rho>0] = ",round(mean(rhovals>0),2))
      }
      title(main=mymain, line=2.5, cex.main=0.8)
    }
  }
  for(j in 1:nm){
    m = models[[j]]      
    if(m$nt>1 & m$nc>1){
      postGamma = getPostEstimate(m, parName="Gamma")
      plotGamma(m, post=postGamma, supportLevel = support.level.gamma, param="Sign",
                covNamesNumbers = c(TRUE,FALSE),
                trNamesNumbers=c(m$nt<21,FALSE),
                cex=c(0.6,0.6,0.8))
      title(main=paste0("GammaPlot ",modelnames[j]), line=2.5,cex.main=0.8)
    }
  }
  for(j in 1:nm){
    m = models[[j]]
    if(m$nr>0 & m$ns>1){
      OmegaCor = computeAssociations(m)
      for (r in 1:m$nr){
        toPlot = ((OmegaCor[[r]]$support>support.level.omega) + (OmegaCor[[r]]$support<(1-support.level.omega))>0)*sign(OmegaCor[[r]]$mean)
        if(is.null(show.sp.names.omega)){
          c.show.sp.names = (m$ns<=30) 
        } else {
          c.show.sp.names = show.sp.names.omega[j]
        }
        if(!c.show.sp.names){
          colnames(toPlot)=rep("",m$ns)
          rownames(toPlot)=rep("",m$ns)
        }
        if(all(omega.order[[j]]==0)){
          plotOrder = 1:m$ns
        } else {
          if(all(omega.order[[j]]=="AOE")){
            plotOrder = corrMatOrder(OmegaCor[[r]]$mean,order="AOE")
          } else {
            plotOrder = omega.order[[j]]
          }
        }
        cat(c("\n","omega.order","\n","\n"),file=text.file,sep="",append=TRUE)
        cat(m$spNames[plotOrder],file=text.file,sep="\n",append=TRUE)
        mymain = paste0("Associations, ",modelnames[j], ": ",names(m$ranLevels)[[r]])
        if(m$ranLevels[[r]]$sDim>0){
          mpost = convertToCodaObject(m)
          alphavals = unlist(poolMcmcChains(mpost$Alpha[[1]][,1]))
          mymain = paste0(mymain,", E[alpha1] = ",round(mean(alphavals),2),", Pr[alpha1>0] = ",round(mean(alphavals>0),2))
        }
        corrplot(toPlot[plotOrder,plotOrder], method = "color",
                 col=colorRampPalette(c("blue","white","red"))(3),
                 mar=c(0,0,1,0),
                 main=mymain,cex.main=0.8)
        me = as.data.frame(OmegaCor[[r]]$mean)
        me = cbind(m$spNames,me)
        colnames(me)[1] = ""
        po = as.data.frame(OmegaCor[[r]]$support)
        po = cbind(m$spNames,po)
        colnames(po)[1] = ""
        ne = as.data.frame(1-OmegaCor[[r]]$support)
        ne = cbind(m$spNames,ne)
        colnames(ne)[1] = ""
        vals = list("Posterior mean"=me,"Pr(x>0)"=po,"Pr(x<0)"=ne)
        filename = file.path(resultDir, paste("parameter_estimates_Omega_",modelnames[j],"_",names(m$ranLevels)[[r]],".xlsx"))
        writexl::write_xlsx(vals,path = filename)
      }
    }
  }
  dev.off()
}


#S7_make_predictions
#
# Set the base directory using your favorite method
# setwd("...")

##################################################################################################
# INPUT AND OUTPUT OF THIS SCRIPT (BEGINNING)
##################################################################################################
#	INPUT. the Fitted models.

#	OUTPUT. Predictions over environmental gradients (for highest RUN of S2) in the file
# "results/predictions.pdf".
##################################################################################################
# INPUT AND OUTPUT OF THIS SCRIPT (END)
##################################################################################################


##################################################################################################
# MAKE THE SCRIPT REPRODUCIBLE (BEGINNING)
##################################################################################################
set.seed(1)
##################################################################################################
## MAKE THE SCRIPT REPRODUCIBLE (END)
##################################################################################################


##################################################################################################
# SETTING COMMONLY ADJUSTED PARAMETERS TO NULL WHICH CORRESPONDS TO DEFAULT CHOICE (BEGINNING)
##################################################################################################
#species.list = NULL #one example species shown for each model,
#selected as prevalence closest to 0.5 (probit models) or most abundant species (other models)
trait.list = NULL #community weighted mean shown for all traits
env.list = NULL #predictions constructed over all environmental gradients
##################################################################################################
# SETTING COMMONLY ADJUSTED PARAMETERS TO NULL WHICH CORRESPONDS TO DEFAULT CHOICE (END)
##################################################################################################

##################################################################################################
# CHANGE DEFAULT OPTIONS BY REMOVING COMMENT AND SETTING VALUE (BEGINNING)
# NOTE THAT THIS IS THE ONLY SECTION OF THE SCRIPT THAT YOU TYPICALLY NEED TO MODIFY
##################################################################################################
#use species.list to select which species are used as examples for which predictions are shown
#species.list should be a list of length the number of models. 
#for each element provide either 0 (use default) or a vector of species indices
species.list = list()
species.list[[1]] = 1:11
species.list[[2]] = 1:11

#use trait.list to select for which traits predictions for community weighted mean traits are shown
#trait.list should be a list of length the number of models. 
#for each element provide either 0 (use default) or a vector of trait indices
#see models[[j]]$trNames to see which trait each index corresponds to
#trait.list = list()
#trait.list[[1]] = c(2,10)
#trait.list[[2]] = 0

#use env.list to select over which environmental gradients predictions are generated
#env.list should be a list of length the number of models. 
#for each element provide either 0 (use default) or a vector of environmental variables
#env.list = list()
#env.list[[1]] = 0
#env.list[[2]] = c("tree","decay")
##################################################################################################
# CHANGE DEFAULT OPTIONS BY REMOVING COMMENT AND SETTING VALUE (END)
# NOTE THAT THIS IS THE ONLY SECTION OF THE SCRIPT THAT YOU TYPICALLY NEED TO MODIFY
##################################################################################################

##################################################################################################
# SET DIRECTORIES (BEGINNING)
##################################################################################################
localDir = "."
modelDir = file.path(localDir, "models")
resultDir = file.path(localDir, "results")
if (!dir.exists(resultDir)) dir.create(resultDir)
##################################################################################################
# SET DIRECTORIES (END)
##################################################################################################


library(Hmsc)
library(ggplot2)

samples_list = c(5,250,250,250,250,250)
thin_list = c(1,1,10,100,1000,10000)
nst = length(thin_list)
nChains = 4

for (Lst in nst:1) {
  thin = thin_list[Lst]
  samples = samples_list[Lst]
  filename = file.path(modelDir,paste("models_thin_", as.character(thin),
                                      "_samples_", as.character(samples),
                                      "_chains_",as.character(nChains),
                                      ".Rdata",sep = ""))
  if(file.exists(filename)){break}
}
if(file.exists(filename)){
  load(filename)
  nm = length(models)
  modelnames = names(models)
  if(is.null(species.list)){
    species.list = list()
    for(j in 1:nm) species.list[[j]] = 0
  }
  if(is.null(trait.list)){
    trait.list = list()
    for(j in 1:nm) trait.list[[j]] = 0
  }
  if(is.null(env.list)){
    env.list = list()
    for(j in 1:nm) env.list[[j]] = 0
  }
  
  pdf(file= file.path(resultDir,"predictions.pdf"))
  for(j in 1:nm){
    m = models[[j]]
    if(all(env.list[[j]]==0)){
      if(m$XFormula=="~."){
        covariates = colnames(m$XData)
      } else {
        covariates = all.vars(m$XFormula)
      }
    } else {
      covariates = env.list[[j]]
    }
    ex.sp = which.max(colMeans(m$Y,na.rm = TRUE)) #most common species as example species
    if(m$distr[1,1]==2){
      ex.sp = which.min(abs(colMeans(m$Y,na.rm = TRUE)-0.5))
    }
    if(!all(species.list[[j]])==0){
      ex.sp = species.list[[j]]
    }
    if(length(covariates)>0){
      for(k in 1:(length(covariates))){
        covariate = covariates[[k]]
        Gradient = constructGradient(m,focalVariable = covariate)
        Gradient2 = constructGradient(m,focalVariable = covariate,non.focalVariables = 1)
        predY = predict(m, Gradient=Gradient, expected = TRUE)  
        predY2 = predict(m, Gradient=Gradient2, expected = TRUE)  
        par(mfrow=c(2,1))
        pl = plotGradient(m, Gradient, pred=predY, yshow = 0, measure="S", showData = TRUE, 
                          main = paste0(modelnames[j],": summed response (total effect)"))
        if(inherits(pl, "ggplot")){
          print(pl + labs(title=paste0(modelnames[j],": summed response (total effect)")))
        }
        pl = plotGradient(m, Gradient2, pred=predY2, yshow = 0, measure="S", showData = TRUE, 
                          main = paste0(modelnames[j],": summed response (marginal effect)"))
        if(inherits(pl, "ggplot")){
          print(pl + labs(title=paste0(modelnames[j],": summed response (marginal effect)")))
        }
        for(l in 1:length(ex.sp)){
          par(mfrow=c(2,1))
          pl = plotGradient(m, Gradient, pred=predY, yshow = if(m$distr[1,1]==2){c(-0.1,1.1)}else{0}, measure="Y",index=ex.sp[l], showData = TRUE, 
                            main = paste0(modelnames[j],": example species (total effect)"))
          if(inherits(pl, "ggplot")){
            print(pl + labs(title=paste0(modelnames[j],": example species (total effect)")))
          }
          pl = plotGradient(m, Gradient2, pred=predY2, yshow = if(m$distr[1,1]==2){c(-0.1,1.1)}else{0}, measure="Y",index=ex.sp[l], showData = TRUE, 
                            main = paste0(modelnames[j],": example species (marginal effect)"))
          if(inherits(pl, "ggplot")){
            print(pl + labs(title=paste0(modelnames[j],": example species (marginal effect)")))
          }
        }
        if(m$nt>1){
          traitSelection = 2:m$nt
          if(!all(trait.list[[j]]==0)) traitSelection = trait.list[[j]]
          for(l in traitSelection){
            par(mfrow=c(2,1))
            pl = plotGradient(m, Gradient, pred=predY, measure="T",index=l, showData = TRUE,yshow = 0,
                              main = paste0(modelnames[j],": community weighted mean trait (total effect)"))
            if(inherits(pl, "ggplot")){
              print(pl + labs(title=paste0(modelnames[j],": community weighted mean trait (total effect)")))
            }
            pl = plotGradient(m, Gradient2, pred=predY2, measure="T",index=l, showData = TRUE, yshow = 0,
                              main = paste0(modelnames[j],": community weighted mean trait (marginal effect)"))
            if(inherits(pl, "ggplot")){
              print(pl + labs(title=paste0(modelnames[j],": community weighted mean trait (marginal effect)")))
            }
          }
        }
      }
    }
  }
  dev.off()
}

#figure_editing
#
library(tidyverse)
library(Hmsc)
library(corrplot)
library(patchwork)
library(terra)
library(sf)
library(gganimate)
library(R.utils)
library(reshape2)
library(abind)


# read in final model 
nChains = 4
samples = 250
thin = 100
filename = paste("models/models_thin_", as.character(thin),
                 "_samples_", as.character(samples),
                 "_chains_",as.character(nChains),
                 ".Rdata",sep = "")
load(filename)
nm = length(models)
m1 <- models[[1]] # presence/absence model
m2 <- models[[2]] # Abundance conditional of presence model


# Variance partitioning plots  ----

# Presence absence model m1
 
# read in parameter estimates VP data from the panels folder. These data and csv file are created seperately using the HMSC workflow
dat_pa_vp <- read.csv(
  "results/parameter_estimates_VP_ pa .csv",
  stringsAsFactors = TRUE)

names(dat_pa_vp)

# Tjur R2 data    
dat_tjurr2 <- dat_pa_vp %>%
  pivot_longer(cols = 2:12, # need to change column range!
               names_to = "species",
               values_to = "vp") %>%
  mutate(species = str_replace(species, "_", " "),
         species = capitalize(species)) %>%
  filter(X == "TjurR2")   

dat_tjurr2$species <- factor(dat_tjurr2$species,
                             levels = c("Caligus",
                                        "Lernanthropus",
                                        "Diplectanum",
                                        "OtherNematodes",
                                        "Cucullanid",
                                        "Ascarid",
                                        "Orientodiploproctodaeum",
                                        "Stephanostomum",
                                        "Pleorchis",
                                        "Hemiuridae",
                                        "Opecoelidae"),
                             labels = c("Caligus sp",
                                        "Lernanthropus paracruciatus",
                                        "Diplectanum spp.",
                                        "Other Nematodes",
                                        "Cucullanidae",
                                        "Ascarididae",
                                        "Orientodiploproctodaeum sp.",
                                        "Stephanostomum sp.",
                                        "Pleorchis sp.",
                                        "Hemiuridae",
                                        "Opecoelidae"),
)


# VP data and switch to long format for plotting
dat_pa_vp_long <- dat_pa_vp %>%
  pivot_longer(cols = 2:12, # NEED TO CHANGE ACCORDING TO NUMBER OF COLUMS
               names_to = "species",
               values_to = "vp") %>%
  #mutate(species = as.factor(species)) %>%
  filter(!X == "TjurR2") %>% # remove the Tjur R2 values for plot
  droplevels() %>% # need this to drop the level Tjur r2 from the factors
  mutate(species = str_replace(species, "_", " "),
         species = capitalize(species)) %>%
  glimpse()


levels(dat_pa_vp_long$X)

dat_pa_vp_long$X <- factor(dat_pa_vp_long$X,
                           levels = c("Random: Location",
                                      "Random: Year",
                                      "Length",
                                      "Sex",
                                      "Season",
                                      "LowDO",
                                      "LowTemp",
                                      "Salinity",
                                      "TDN",
                                      "TDP",
                                      "NH"),
                           labels = c("Random: Location",
                                      "Random: Year",
                                      "Length",
                                      "Sex",
                                      "Season",
                                      "Low DO",
                                      "Low Temp",
                                      "Salinity",
                                      "TDN",
                                      "TDP",
                                      "NH"),
)


dat_pa_vp_long$species <- factor(dat_pa_vp_long$species,
                                 levels = c("Caligus",
                                            "Lernanthropus",
                                            "Diplectanum",
                                            "OtherNematodes",
                                            "Cucullanid",
                                            "Ascarid",
                                            "Orientodiploproctodaeum",
                                            "Stephanostomum",
                                            "Pleorchis",
                                            "Hemiuridae",
                                            "Opecoelidae"),
                                 labels = c("Caligus sp",
                                            "Lernanthropus paracruciatus",
                                            "Diplectanum spp.",
                                            "Other Nematodes",
                                            "Cucullanidae",
                                            "Ascarididae",
                                            "Orientodiploproctodaeum sp.",
                                            "Stephanostomum sp.",
                                            "Pleorchis sp.",
                                            "Hemiuridae",
                                            "Opecoelidae"),
)



p1 <- ggplot(dat_tjurr2) +
  geom_bar(stat = "identity", aes(y = vp, x = species)) +
  scale_x_discrete(limits=rev) +
  coord_flip() +
  scale_y_continuous(expand = c(0, 0), limits = c(0, 1.1)) +
  ylab(expression(Tjur~R^{"2"})) +
  xlab("") +
  theme_light() +
  theme(axis.text.y = element_text(face=c("plain","plain","italic","italic","italic","plain","plain","plain",
                                          "italic","italic","italic")))
p1         

p2 <- ggplot(data = dat_pa_vp_long) + 
  geom_bar(position="stack", stat="identity", aes(fill=X, y=vp, x=species)) +
  scale_x_discrete(limits=rev) +
  coord_flip() +
  scale_y_continuous(expand = c(0, 0), limits = c(0, 1.01)) +
  ylab("Proportion of variance explained") +
  xlab("") +
  scale_fill_manual(values = c("grey40", "grey88", 
                               "slategray2", "hotpink", "palegreen", "yellow2", "yellow4",
                               "cadetblue", "orange", "darkorange3", "firebrick4", "firebrick4")) +
  theme_light() +
  theme(legend.title=element_blank(),
        axis.text.y = element_text(face=c("plain","plain","italic","italic","italic","plain","plain","plain",
                                          "italic","italic","italic"))) 
p2

pa_vp_plot <- p1 + p2 + plot_annotation(tag_levels = 'A')
pa_vp_plot
ggsave("Figures/hmsc_vp_pa.png", pa_vp_plot, height = 20, width = 40, units = "cm")




# Abundance COP plots
dat_acop_vp <- read.csv(
  "results/parameter_estimates_VP_ abuc .csv",
  stringsAsFactors = TRUE)

names(dat_acop_vp)



## Split data into Tjur r2 and VP data

# Tjur R2    
dat_r2 <- dat_acop_vp %>%
  pivot_longer(cols = 2:12,
               names_to = "species",
               values_to = "vp") %>%
  filter(X == "R2") %>%
  mutate(species = str_replace(species, "_", " "),
         species = capitalize(species))

dat_r2$species <- factor(dat_r2$species,
                         levels = c("Caligus",
                                    "Lernanthropus",
                                    "Diplectanum",
                                    "OtherNematodes",
                                    "Cucullanid",
                                    "Ascarid",
                                    "Orientodiploproctodaeum",
                                    "Stephanostomum",
                                    "Pleorchis",
                                    "Hemiuridae",
                                    "Opecoelidae"),
                         labels = c("Caligus sp",
                                    "Lernanthropus paracruciatus",
                                    "Diplectanum spp.",
                                    "Other Nematodes",
                                    "Cucullanidae",
                                    "Ascarididae",
                                    "Orientodiploproctodaeum sp.",
                                    "Stephanostomum sp.",
                                    "Pleorchis sp.",
                                    "Hemiuridae",
                                    "Opecoelidae"),
)

# VP data and switch to long format for plotting
dat_acop_vp_long <- dat_acop_vp %>%
  pivot_longer(cols = 2:12, # NEED TO CHANGE ACCORDING TO NUMBER OF COLUMS
               names_to = "species",
               values_to = "vp") %>%
  #mutate(species = as.factor(species)) %>%
  filter(!X == "R2") %>% # remove the Tjur R2 values for plot
  droplevels() %>% # need this to drop the level Tjur r2 from the factors
  mutate(species = str_replace(species, "_", " "),
         species = capitalize(species)) %>%
  glimpse()

levels(dat_acop_vp_long$X)

dat_acop_vp_long$X <- factor(dat_acop_vp_long$X,
                             levels = c("Random: Location",
                                        "Random: Year",
                                        "Length",
                                        "Sex",
                                        "Season",
                                        "LowDO",
                                        "LowTemp",
                                        "Salinity",
                                        "TDN",
                                        "TDP",
                                        "NH"),
                             labels = c("Random: Location",
                                        "Random: Year",
                                        "Length",
                                        "Sex",
                                        "Season",
                                        "Low DO",
                                        "Low Temp",
                                        "Salinity",
                                        "TDN",
                                        "TDP",
                                        "NH"),
)


dat_acop_vp_long$species <- factor(dat_acop_vp_long$species,
                                   levels = c("Caligus",
                                              "Lernanthropus",
                                              "Diplectanum",
                                              "OtherNematodes",
                                              "Cucullanid",
                                              "Ascarid",
                                              "Orientodiploproctodaeum",
                                              "Stephanostomum",
                                              "Pleorchis",
                                              "Hemiuridae",
                                              "Opecoelidae"),
                                   labels = c("Caligus sp",
                                              "Lernanthropus paracruciatus",
                                              "Diplectanum spp.",
                                              "Other Nematodes",
                                              "Cucullanidae",
                                              "Ascarididae",
                                              "Orientodiploproctodaeum sp.",
                                              "Stephanostomum sp.",
                                              "Pleorchis sp.",
                                              "Hemiuridae",
                                              "Opecoelidae"),
)



p3 <- ggplot(dat_r2) +
  geom_bar(stat = "identity", aes(y = vp, x = species)) +
  scale_x_discrete(limits=rev) +
  coord_flip() +
  scale_y_continuous(expand = c(0, 0), limits = c(0, 1.1)) +
  ylab(expression(~R^{"2"})) +
  xlab("") +
  theme_light() +
  theme(axis.text.y = element_text(face=c("plain","plain","italic","italic","italic","plain","plain","plain",
                                          "italic","italic","italic")))
p3

p4 <- ggplot(data = dat_acop_vp_long) + 
  geom_bar(position="stack", stat="identity", aes(fill=X, y=vp, x=species)) +
  scale_x_discrete(limits=rev) +
  coord_flip() +
  scale_y_continuous(expand = c(0, 0), limits = c(0, 1.01)) +
  ylab("Proportion of variance explained") +
  xlab("") +
  scale_fill_manual(values = c("grey40", "grey88", 
                               "slategray2", "hotpink", "palegreen", "yellow2", "yellow4",
                               "cadetblue", "orange", "darkorange3", "firebrick4")) +
  theme_light() +
  theme(legend.title=element_blank(),
        axis.text.y = element_text(face=c("plain","plain","italic","italic","italic","plain","plain","plain",
                                          "italic","italic","italic"))) 
p4

acop_vp_plot <- p3 + p4 + plot_annotation(tag_levels = 'A')
acop_vp_plot
ggsave("Figures/hmsc_vp_acop.png", acop_vp_plot, height = 20, width = 40, units = "cm")



# Combine all 4 variance partition plots
vp_plot <- (p1 + p2) / (p3 + p4) + plot_annotation(tag_levels = 'A')
vp_plot
ggsave("Figures/hmsc_vp.png", vp_plot, height = 30, width = 30, units = "cm")







# Beta heatmap ----

# Presence absence

postBeta_pa = getPostEstimate(m1, parName="Beta")
mbeta_pa=postBeta_pa$mean
betaP_pa=postBeta_pa$support
supportLevel = 0.95
toPlot_pa = sign(mbeta_pa)
toPlot_pa = toPlot_pa * ((betaP_pa>supportLevel) + (betaP_pa<(1-supportLevel))>0)
betaMat_pa = matrix(toPlot_pa, nrow=m1$nc, ncol=ncol(m1$Y))
betaMat_pa = as.data.frame(betaMat_pa)
colnames(betaMat_pa) = gsub(" ", "_", m1$spNames)



rownames(betaMat_pa) = m1$covNames

betaMat_DF_pa <- betaMat_pa %>% 
  as.data.frame() %>%
  rownames_to_column("covNames") %>%
  pivot_longer(-c(covNames), names_to = "species", values_to = "beta") %>%
  mutate(beta = as.factor(beta),
         species = str_replace(species, "_", " "),
         species = capitalize(species))

betaMat_DF_pa$species <- factor(betaMat_DF_pa$species,
                                levels = c("Caligus",
                                           "Lernanthropus",
                                           "Diplectanum",
                                           "OtherNematodes",
                                           "Cucullanid",
                                           "Ascarid",
                                           "Orientodiploproctodaeum",
                                           "Stephanostomum",
                                           "Pleorchis",
                                           "Hemiuridae",
                                           "Opecoelidae"),
                                labels = c("Caligus sp",
                                           "Lernanthropus paracruciatus",
                                           "Diplectanum spp.",
                                           "Other Nematodes",
                                           "Cucullanidae",
                                           "Ascarididae",
                                           "Orientodiploproctodaeum sp.",
                                           "Stephanostomum sp.",
                                           "Pleorchis sp.",
                                           "Hemiuridae",
                                           "Opecoelidae"),
)

betaMat_DF_pa$covNames <- factor(betaMat_DF_pa$covNames, 
                                 levels = c("(Intercept)", 
                                            "Random: Location",
                                            "Random: Year",
                                            "Length",
                                            "SexM",
                                            "SeasonDry",
                                            "SeasonWet",
                                            "LowDO",
                                            "LowTemp",
                                            "Salinity",
                                            "TDN",
                                            "TDP",
                                            "NH"),
                                 labels = c("Intercept",
                                            "Random: Location",
                                            "Random: Year",
                                            "Length",
                                            "Sex",
                                            "Season Dry",
                                            "Season Wet",
                                            "Low DO",
                                            "Low Temp",
                                            "Salinity",
                                            "TDN",
                                            "TDP",
                                            "NH"),
)

# make sure to run ALL the data prep code first as it uses the same object names for both models/figures. 
pa_beta_plot <- ggplot(betaMat_DF_pa, aes(covNames, species, fill= beta)) + 
  geom_tile(col = "grey") +
  scale_y_discrete(limits=rev) +
  ylab("") +
  xlab("") +
  scale_fill_manual(values = c("steelblue","white","tomato"),
                    name="Statistical\nsupport",
                    labels=c("Negative response", "Not supported", "Positive response"),
                    guide = guide_legend(reverse=TRUE)) +
  theme_light() +
  theme(  axis.text.x  = element_text(angle=90, vjust=0.5, hjust = 1),
          axis.text.y = element_text(face=c("plain","plain","italic","italic","italic","plain","plain","plain",
                                            "italic","italic","italic")))
pa_beta_plot

ggsave("Figures/hmsc_beta_pa.png", pa_beta_plot, height = 25, width = 25, units = "cm")



# Abundance COP Beta plot

postBeta_acop = getPostEstimate(m2, parName="Beta")


mbeta_acop=postBeta_acop$mean
betaP_acop=postBeta_acop$support
supportLevel = 0.95
toPlot_acop = sign(mbeta_acop)
toPlot_acop = toPlot_acop * ((betaP_acop>supportLevel) + (betaP_acop<(1-supportLevel))>0)
betaMat_acop = matrix(toPlot_acop, nrow=m2$nc, ncol=ncol(m2$Y))
betaMat_acop = as.data.frame(betaMat_acop)

colnames(betaMat_acop) = gsub(" ", "_", m2$spNames)
rownames(betaMat_acop) = m2$covNames
betaMat_acop <- betaMat_acop[, rev(order(colnames(betaMat)))]


betaMat_DF_acop <- betaMat_acop %>% 
  as.data.frame() %>%
  rownames_to_column("covNames") %>%
  pivot_longer(-c(covNames), names_to = "species", values_to = "beta") %>%
  mutate(beta = as.factor(beta),
         species = str_replace(species, "_", " "),
         species = capitalize(species))

betaMat_DF_acop$species <- factor(betaMat_DF_acop$species,
                                  levels = c("Caligus",
                                             "Lernanthropus",
                                             "Diplectanum",
                                             "OtherNematodes",
                                             "Cucullanid",
                                             "Ascarid",
                                             "Orientodiploproctodaeum",
                                             "Stephanostomum",
                                             "Pleorchis",
                                             "Hemiuridae",
                                             "Opecoelidae"),
                                  labels = c("Caligus sp",
                                             "Lernanthropus paracruciatus",
                                             "Diplectanum spp.",
                                             "Other Nematodes",
                                             "Cucullanidae",
                                             "Ascarididae",
                                             "Orientodiploproctodaeum sp.",
                                             "Stephanostomum sp.",
                                             "Pleorchis sp.",
                                             "Hemiuridae",
                                             "Opecoelidae"),
)

betaMat_DF_acop$covNames <- factor(betaMat_DF_acop$covNames, 
                                   levels = c("(Intercept)", 
                                              "Random: Location",
                                              "Random: Year",
                                              "Length",
                                              "SexM",
                                              "SeasonDry",
                                              "SeasonWet",
                                              "LowDO",
                                              "LowTemp",
                                              "Salinity",
                                              "TDN",
                                              "TDP",
                                              "NH"),
                                   labels = c("Intercept",
                                              "Random: Location",
                                              "Random: Year",
                                              "Length",
                                              "Sex",
                                              "Season Dry",
                                              "Season Wet",
                                              "Low DO",
                                              "Low Temp",
                                              "Salinity",
                                              "TDN",
                                              "TDP",
                                              "NH"),
)





acop_beta_plot <- ggplot(betaMat_DF_acop, aes(covNames, species, fill= beta)) + 
  geom_tile(col = "lightgrey") +
  scale_y_discrete(limits=rev) +
  ylab("") +
  xlab("") +
  scale_fill_manual(values = c("steelblue","white","tomato"),
                    name="Statistical\nsupport",
                    labels=c("Negative response", "Not supported", "Positive response"),
                    guide = guide_legend(reverse=TRUE)) +
  theme_light() +
  theme(  axis.text.x  = element_text(angle=90, vjust=0.5, hjust = 1),
          axis.text.y = element_text(face=c("plain","plain","italic","italic","italic","plain","plain","plain",
                                            "italic","italic","italic")))
acop_beta_plot

ggsave("Figures/hmsc_beta_acop.png", acop_beta_plot, height = 25, width = 25, units = "cm")


# Combine the 2 beta plots
beta_plot <- pa_beta_plot / acop_beta_plot + plot_annotation(tag_levels = 'A')
beta_plot
ggsave("Figures/hmsc_beta_plots.png", beta_plot, height = 35, width = 20, units = "cm")








# Gradient plots species richness ----


# Length
m1$covNames
focalVariable = "Length"

Gradient = constructGradient(m1,focalVariable = focalVariable) # REPLACE with variable of interst
predY = predict(m1, Gradient=Gradient, expected = TRUE)
plotGradient(m1, Gradient, pred=predY, measure="Y", index = 6, showData = TRUE)

# Species richness
ngrid = length(predY)
predS = abind(lapply(predY, rowSums),along=2)
Pr = mean(predS[ngrid,]>predS[1,])
q = c(0.025, 0.5, 0.975)
qpred = apply(predS, c(1), quantile,
              probs = q, na.rm=TRUE)
qpred = qpred[, , index]
qpred_long <- t(qpred)
dat <- cbind(Gradient$XDataNew, qpred_long)

gradient_plot_length <- ggplot(dat, aes(x = Length, y = `50%`)) +
  geom_smooth(fill = "skyblue", aes(ymin = `2.5%`, ymax = `97.5%`), stat = "identity") +
  geom_line(size = 2, col = "navyblue") +
  #ylim(0,11) +
  ylab("Species Richness") +
  xlab("Length (cm)") +
  theme_classic() +
  theme(text = element_text(size = 6)) 
gradient_plot_length
ggsave(paste("Figures/Gradient_pa_length_richness",".png"), gradient_plot_length, height = 5, width = 5, units = "cm")






# LowTemp
m1$covNames
focalVariable = "LowTemp"

Gradient = constructGradient(m1,focalVariable = focalVariable) # REPLACE with variable of interst
predY = predict(m1, Gradient=Gradient, expected = TRUE)
plotGradient(m1, Gradient, pred=predY, measure="Y", index = 6, showData = TRUE)

# Species richness
ngrid = length(predY)
predS = abind(lapply(predY, rowSums),along=2)
Pr = mean(predS[ngrid,]>predS[1,])
q = c(0.025, 0.5, 0.975)
qpred = apply(predS, c(1), quantile,
              probs = q, na.rm=TRUE)
qpred = qpred[, , index]
qpred_long <- t(qpred)
dat <- cbind(Gradient$XDataNew, qpred_long)

xlab <- "Temperature (°C)"

gradient_plot_temp <- ggplot(dat, aes(x = LowTemp, y = `50%`)) +
  geom_smooth(fill = "skyblue", aes(ymin = `2.5%`, ymax = `97.5%`), stat = "identity") +
  geom_line(size = 2, col = "navyblue") +
  ylim(0,8) +
  ylab("Species Richness") +
  labs(x=xlab) +
  theme_classic() +
  theme(text = element_text(size = 6)) 
gradient_plot_temp
ggsave(paste("Figures/Gradient_pa_lowtemp_richness",".png"), gradient_plot_temp, height = 5, width = 5, units = "cm")




# Salinity
m1$covNames
focalVariable = "Salinity"

Gradient = constructGradient(m1,focalVariable = focalVariable) # REPLACE with variable of interst
predY = predict(m1, Gradient=Gradient, expected = TRUE)
plotGradient(m1, Gradient, pred=predY, measure="Y", index = 6, showData = TRUE)

# Species richness
ngrid = length(predY)
predS = abind(lapply(predY, rowSums),along=2)
Pr = mean(predS[ngrid,]>predS[1,])
q = c(0.025, 0.5, 0.975)
qpred = apply(predS, c(1), quantile,
              probs = q, na.rm=TRUE)
qpred = qpred[, , index]
qpred_long <- t(qpred)
dat <- cbind(Gradient$XDataNew, qpred_long)

gradient_plot_sal <- ggplot(dat, aes(x = Salinity, y = `50%`)) +
  geom_smooth(fill = "skyblue", aes(ymin = `2.5%`, ymax = `97.5%`), stat = "identity") +
  geom_line(size = 2, col = "navyblue") +
  ylim(0,8) +
  ylab("Species Richness") +
  xlab("Salinity") +
  theme_classic() +
  theme(text = element_text(size = 6)) 
gradient_plot_sal
ggsave(paste("Figures/Gradient_pa_salinity_richness",".png"), gradient_plot_sal, height = 5, width = 5, units = "cm")


gradient_plot <- gradient_plot_length / gradient_plot_temp / gradient_plot_sal + plot_annotation(tag_levels = 'A')
gradient_plot
ggsave("Figures/gradient_plots_pa.png", gradient_plot, height = 15, width = 7, units = "cm")


# Gradient plots abundance ----
# Length
m2$covNames
focalVariable = "Length"

Gradient = constructGradient(m2,focalVariable = focalVariable) # REPLACE with variable of interst
predY = predict(m2, Gradient=Gradient, expected = TRUE)
plotGradient(m1, Gradient, pred=predY, measure="S", showData = TRUE)

# Species richness
ngrid = length(predY)
predS = abind(lapply(predY, rowSums),along=2)
Pr = mean(predS[ngrid,]>predS[1,])
q = c(0.025, 0.5, 0.975)
qpred = apply(predS, c(1), quantile,
              probs = q, na.rm=TRUE)
qpred = qpred[, , index]
qpred_long <- t(qpred)
dat <- cbind(Gradient$XDataNew, qpred_long)

gradient_plot <- ggplot(dat, aes(x = Length, y = `50%`)) +
  geom_smooth(fill = "skyblue", aes(ymin = `2.5%`, ymax = `97.5%`), stat = "identity") +
  geom_line(size = 2, col = "navyblue") +
  #ylim(0,11) +
  ylab("Abundace") +
  xlab("Length") +
  theme_classic() +
  theme(text = element_text(size = 6)) 
gradient_plot
ggsave(paste("Figures/Gradient_pa_length_abundance",".png"), gradient_plot, height = 5, width = 5, units = "cm")






# LowTemp
m2$covNames
focalVariable = "LowTemp"

Gradient = constructGradient(m2,focalVariable = focalVariable) # REPLACE with variable of interst
predY = predict(m2, Gradient=Gradient, expected = TRUE)
plotGradient(m1, Gradient, pred=predY, measure="Y", index = 6, showData = TRUE)

# Species richness
ngrid = length(predY)
predS = abind(lapply(predY, rowSums),along=2)
Pr = mean(predS[ngrid,]>predS[1,])
q = c(0.025, 0.5, 0.975)
qpred = apply(predS, c(1), quantile,
              probs = q, na.rm=TRUE)
qpred = qpred[, , index]
qpred_long <- t(qpred)
dat <- cbind(Gradient$XDataNew, qpred_long)

gradient_plot <- ggplot(dat, aes(x = LowTemp, y = `50%`)) +
  geom_smooth(fill = "skyblue", aes(ymin = `2.5%`, ymax = `97.5%`), stat = "identity") +
  geom_line(size = 2, col = "navyblue") +
  #ylim(0,8) +
  ylab("Abundance") +
  xlab("Low Temperature") +
  theme_classic() +
  theme(text = element_text(size = 6)) 
gradient_plot
ggsave(paste("Figures/Gradient_pa_lowtemp_abundance",".png"), gradient_plot, height = 5, width = 5, units = "cm")




# Salinity
m2$covNames
focalVariable = "Salinity"

Gradient = constructGradient(m2,focalVariable = focalVariable) # REPLACE with variable of interst
predY = predict(m2, Gradient=Gradient, expected = TRUE)
plotGradient(m2, Gradient, pred=predY, measure="Y", index = 6, showData = TRUE)

# Species richness
ngrid = length(predY)
predS = abind(lapply(predY, rowSums),along=2)
Pr = mean(predS[ngrid,]>predS[1,])
q = c(0.025, 0.5, 0.975)
qpred = apply(predS, c(1), quantile,
              probs = q, na.rm=TRUE)
qpred = qpred[, , index]
qpred_long <- t(qpred)
dat <- cbind(Gradient$XDataNew, qpred_long)

gradient_plot <- ggplot(dat, aes(x = Salinity, y = `50%`)) +
  geom_smooth(fill = "skyblue", aes(ymin = `2.5%`, ymax = `97.5%`), stat = "identity") +
  geom_line(size = 2, col = "navyblue") +
  #ylim(0,8) +
  ylab("Abundance") +
  xlab("Salinity") +
  theme_classic() +
  theme(text = element_text(size = 6)) 
gradient_plot
ggsave(paste("Figures/Gradient_pa_salinity_abundance",".png"), gradient_plot, height = 5, width = 5, units = "cm")




